Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Cognito Sync.

Actions, resources, and condition keys for Amazon Cognito Sync - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Cognito Sync

Amazon Cognito Sync (service prefix: `cognito-sync` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Cognito Sync
- Resource types defined by Amazon Cognito Sync
- Condition keys for Amazon Cognito Sync

## Actions defined by Amazon Cognito Sync

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BulkPublish | Grants permission to initiate a bulk publish of all existing datasets for an Identity Pool to the configured stream | Write | identitypool* |  |
DeleteDataset | Grants permission to delete a specific dataset | Write | dataset* |  |
DescribeDataset | Grants permission to get metadata about a dataset by identity and dataset name | Read | dataset* |  |
DescribeIdentityPoolUsage | Grants permission to get usage details (for example, data storage) about a particular identity pool | Read | identitypool* |  |
DescribeIdentityUsage | Grants permission to get usage information for an identity, including number of datasets and data usage | Read | identity* |  |
GetBulkPublishDetails | Grants permission to get the status of the last BulkPublish operation for an identity pool | Read | identitypool* |  |
GetCognitoEvents | Grants permission to get the events and the corresponding Lambda functions associated with an identity pool | Read | identitypool* |  |
GetIdentityPoolConfiguration | Grants permission to get the configuration settings of an identity pool | Read | identitypool* |  |
ListDatasets | Grants permission to list datasets for an identity | List | dataset* |  |
ListIdentityPoolUsage | Grants permission to get a list of identity pools registered with Cognito | Read | identitypool* |  |
ListRecords | Grants permission to get paginated records, optionally changed after a particular sync count for a dataset and identity | Read | dataset* |  |
QueryRecords [permission only] | Grants permission to query records | Read |  |  |
RegisterDevice | Grants permission to register a device to receive push sync notifications | Write | identity* |  |
SetCognitoEvents | Grants permission to set the AWS Lambda function for a given event type for an identity pool | Write | identitypool* |  |
SetDatasetConfiguration [permission only] | Grants permission to configure datasets | Write | dataset* |  |
SetIdentityPoolConfiguration | Grants permission to set the necessary configuration for push sync | Write | identitypool* |  |
SubscribeToDataset | Grants permission to subscribe to receive notifications when a dataset is modified by another device | Write | dataset* |  |
UnsubscribeFromDataset | Grants permission to unsubscribe from receiving notifications when a dataset is modified by another device | Write | dataset* |  |
UpdateRecords | Grants permission to post updates to records and add and delete records for a dataset and user | Write | dataset* |  |

## Resource types defined by Amazon Cognito Sync

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
dataset | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}/identity/$ { IdentityId}/dataset/$ { DatasetName}` |
identity | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}/identity/$ { IdentityId}` |
identitypool | `arn:$ { Partition}:cognito-sync:$ { Region}:$ { Account}:identitypool/$ { IdentityPoolId}` |

## Condition keys for Amazon Cognito Sync

Cognito Sync has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.